# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetLogAnalyticsLogGroupsResult',
    'AwaitableGetLogAnalyticsLogGroupsResult',
    'get_log_analytics_log_groups',
    'get_log_analytics_log_groups_output',
]

@pulumi.output_type
class GetLogAnalyticsLogGroupsResult:
    """
    A collection of values returned by getLogAnalyticsLogGroups.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, log_analytics_log_group_summary_collections=None, namespace=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if log_analytics_log_group_summary_collections and not isinstance(log_analytics_log_group_summary_collections, list):
            raise TypeError("Expected argument 'log_analytics_log_group_summary_collections' to be a list")
        pulumi.set(__self__, "log_analytics_log_group_summary_collections", log_analytics_log_group_summary_collections)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier [OCID] (https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name that is changeable and that does not have to be unique. Format: a leading alphanumeric, followed by zero or more alphanumerics, underscores, spaces, backslashes, or hyphens in any order). No trailing spaces allowed.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetLogAnalyticsLogGroupsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="logAnalyticsLogGroupSummaryCollections")
    def log_analytics_log_group_summary_collections(self) -> Sequence['outputs.GetLogAnalyticsLogGroupsLogAnalyticsLogGroupSummaryCollectionResult']:
        """
        The list of log_analytics_log_group_summary_collection.
        """
        return pulumi.get(self, "log_analytics_log_group_summary_collections")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        return pulumi.get(self, "namespace")


class AwaitableGetLogAnalyticsLogGroupsResult(GetLogAnalyticsLogGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogAnalyticsLogGroupsResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            log_analytics_log_group_summary_collections=self.log_analytics_log_group_summary_collections,
            namespace=self.namespace)


def get_log_analytics_log_groups(compartment_id: Optional[str] = None,
                                 display_name: Optional[str] = None,
                                 filters: Optional[Sequence[pulumi.InputType['GetLogAnalyticsLogGroupsFilterArgs']]] = None,
                                 namespace: Optional[str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogAnalyticsLogGroupsResult:
    """
    This data source provides the list of Log Analytics Log Groups in Oracle Cloud Infrastructure Log Analytics service.

    Returns a list of log groups in a compartment. You may limit the number of log groups, provide sorting options, and filter the results by specifying a display name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_log_analytics_log_groups = oci.LogAnalytics.get_log_analytics_log_groups(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only log analytics log groups whose displayName matches the entire display name given. The match is case-insensitive.
    :param str namespace: The Logging Analytics namespace used for the request.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:LogAnalytics/getLogAnalyticsLogGroups:getLogAnalyticsLogGroups', __args__, opts=opts, typ=GetLogAnalyticsLogGroupsResult).value

    return AwaitableGetLogAnalyticsLogGroupsResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        log_analytics_log_group_summary_collections=__ret__.log_analytics_log_group_summary_collections,
        namespace=__ret__.namespace)


@_utilities.lift_output_func(get_log_analytics_log_groups)
def get_log_analytics_log_groups_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                        display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetLogAnalyticsLogGroupsFilterArgs']]]]] = None,
                                        namespace: Optional[pulumi.Input[str]] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLogAnalyticsLogGroupsResult]:
    """
    This data source provides the list of Log Analytics Log Groups in Oracle Cloud Infrastructure Log Analytics service.

    Returns a list of log groups in a compartment. You may limit the number of log groups, provide sorting options, and filter the results by specifying a display name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_log_analytics_log_groups = oci.LogAnalytics.get_log_analytics_log_groups(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only log analytics log groups whose displayName matches the entire display name given. The match is case-insensitive.
    :param str namespace: The Logging Analytics namespace used for the request.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'PrivateApplicationLogo',
    'PrivateApplicationPackageDetails',
    'GetPrivateApplicationLogoResult',
    'GetPrivateApplicationPackageDetailResult',
    'GetPrivateApplicationPackagesFilterResult',
    'GetPrivateApplicationPackagesPrivateApplicationPackageCollectionResult',
    'GetPrivateApplicationPackagesPrivateApplicationPackageCollectionItemResult',
    'GetPrivateApplicationsFilterResult',
    'GetPrivateApplicationsPrivateApplicationCollectionResult',
    'GetPrivateApplicationsPrivateApplicationCollectionItemResult',
    'GetPrivateApplicationsPrivateApplicationCollectionItemLogoResult',
    'GetPrivateApplicationsPrivateApplicationCollectionItemPackageDetailResult',
    'GetServiceCatalogAssociationsFilterResult',
    'GetServiceCatalogAssociationsServiceCatalogAssociationCollectionResult',
    'GetServiceCatalogAssociationsServiceCatalogAssociationCollectionItemResult',
    'GetServiceCatalogsFilterResult',
    'GetServiceCatalogsServiceCatalogCollectionResult',
    'GetServiceCatalogsServiceCatalogCollectionItemResult',
]

@pulumi.output_type
class PrivateApplicationLogo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "contentUrl":
            suggest = "content_url"
        elif key == "displayName":
            suggest = "display_name"
        elif key == "mimeType":
            suggest = "mime_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PrivateApplicationLogo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PrivateApplicationLogo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PrivateApplicationLogo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 content_url: Optional[str] = None,
                 display_name: Optional[str] = None,
                 mime_type: Optional[str] = None):
        """
        :param str content_url: The content URL of the uploaded data.
        :param str display_name: (Updatable) The name of the private application.
        :param str mime_type: The MIME type of the uploaded data.
        """
        if content_url is not None:
            pulumi.set(__self__, "content_url", content_url)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if mime_type is not None:
            pulumi.set(__self__, "mime_type", mime_type)

    @property
    @pulumi.getter(name="contentUrl")
    def content_url(self) -> Optional[str]:
        """
        The content URL of the uploaded data.
        """
        return pulumi.get(self, "content_url")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        (Updatable) The name of the private application.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="mimeType")
    def mime_type(self) -> Optional[str]:
        """
        The MIME type of the uploaded data.
        """
        return pulumi.get(self, "mime_type")


@pulumi.output_type
class PrivateApplicationPackageDetails(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "packageType":
            suggest = "package_type"
        elif key == "zipFileBase64encoded":
            suggest = "zip_file_base64encoded"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PrivateApplicationPackageDetails. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PrivateApplicationPackageDetails.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PrivateApplicationPackageDetails.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 package_type: str,
                 version: str,
                 zip_file_base64encoded: Optional[str] = None):
        """
        :param str package_type: The package's type.
        :param str version: The package version.
        """
        pulumi.set(__self__, "package_type", package_type)
        pulumi.set(__self__, "version", version)
        if zip_file_base64encoded is not None:
            pulumi.set(__self__, "zip_file_base64encoded", zip_file_base64encoded)

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        The package's type.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The package version.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="zipFileBase64encoded")
    def zip_file_base64encoded(self) -> Optional[str]:
        return pulumi.get(self, "zip_file_base64encoded")


@pulumi.output_type
class GetPrivateApplicationLogoResult(dict):
    def __init__(__self__, *,
                 content_url: str,
                 display_name: str,
                 mime_type: str):
        """
        :param str content_url: The content URL of the uploaded data.
        :param str display_name: The name used to refer to the uploaded data.
        :param str mime_type: The MIME type of the uploaded data.
        """
        pulumi.set(__self__, "content_url", content_url)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "mime_type", mime_type)

    @property
    @pulumi.getter(name="contentUrl")
    def content_url(self) -> str:
        """
        The content URL of the uploaded data.
        """
        return pulumi.get(self, "content_url")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The name used to refer to the uploaded data.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="mimeType")
    def mime_type(self) -> str:
        """
        The MIME type of the uploaded data.
        """
        return pulumi.get(self, "mime_type")


@pulumi.output_type
class GetPrivateApplicationPackageDetailResult(dict):
    def __init__(__self__, *,
                 package_type: str,
                 version: str,
                 zip_file_base64encoded: str):
        """
        :param str package_type: Type of packages within this private application.
        """
        pulumi.set(__self__, "package_type", package_type)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "zip_file_base64encoded", zip_file_base64encoded)

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        Type of packages within this private application.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter
    def version(self) -> str:
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="zipFileBase64encoded")
    def zip_file_base64encoded(self) -> str:
        return pulumi.get(self, "zip_file_base64encoded")


@pulumi.output_type
class GetPrivateApplicationPackagesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetPrivateApplicationPackagesPrivateApplicationPackageCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetPrivateApplicationPackagesPrivateApplicationPackageCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetPrivateApplicationPackagesPrivateApplicationPackageCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetPrivateApplicationPackagesPrivateApplicationPackageCollectionItemResult(dict):
    def __init__(__self__, *,
                 content_url: str,
                 display_name: str,
                 id: str,
                 mime_type: str,
                 package_type: str,
                 private_application_id: str,
                 time_created: str,
                 version: str):
        """
        :param str display_name: Exact match name filter.
        :param str id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private application package.
        :param str package_type: Name of the package type. If multiple package types are provided, then any resource with one or more matching package types will be returned.
        :param str private_application_id: The unique identifier for the private application.
        :param str time_created: The date and time the private application package was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-27T21:10:29.600Z`
        :param str version: The package version.
        """
        pulumi.set(__self__, "content_url", content_url)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mime_type", mime_type)
        pulumi.set(__self__, "package_type", package_type)
        pulumi.set(__self__, "private_application_id", private_application_id)
        pulumi.set(__self__, "time_created", time_created)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="contentUrl")
    def content_url(self) -> str:
        return pulumi.get(self, "content_url")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Exact match name filter.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private application package.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mimeType")
    def mime_type(self) -> str:
        return pulumi.get(self, "mime_type")

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        Name of the package type. If multiple package types are provided, then any resource with one or more matching package types will be returned.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter(name="privateApplicationId")
    def private_application_id(self) -> str:
        """
        The unique identifier for the private application.
        """
        return pulumi.get(self, "private_application_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the private application package was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-27T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The package version.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetPrivateApplicationsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetPrivateApplicationsPrivateApplicationCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetPrivateApplicationsPrivateApplicationCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetPrivateApplicationsPrivateApplicationCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetPrivateApplicationsPrivateApplicationCollectionItemResult(dict):
    def __init__(__self__, *,
                 compartment_id: str,
                 defined_tags: Mapping[str, Any],
                 display_name: str,
                 freeform_tags: Mapping[str, Any],
                 id: str,
                 logo_file_base64encoded: str,
                 logos: Sequence['outputs.GetPrivateApplicationsPrivateApplicationCollectionItemLogoResult'],
                 long_description: str,
                 package_details: Sequence['outputs.GetPrivateApplicationsPrivateApplicationCollectionItemPackageDetailResult'],
                 package_type: str,
                 short_description: str,
                 state: str,
                 time_created: str,
                 time_updated: str):
        """
        :param str compartment_id: The unique identifier for the compartment.
        :param Mapping[str, Any] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param str display_name: Exact match name filter.
        :param Mapping[str, Any] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param str id: The unique identifier for the private application in Marketplace.
        :param Sequence['GetPrivateApplicationsPrivateApplicationCollectionItemLogoArgs'] logos: The model for uploaded binary data, like logos and images.
        :param str long_description: A long description of the private application.
        :param str package_type: Type of packages within this private application.
        :param str short_description: A short description of the private application.
        :param str state: The lifecycle state of the private application.
        :param str time_created: The date and time the private application was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-26T21:10:29.600Z`
        :param str time_updated: The date and time the private application was last modified, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-12-10T05:10:29.721Z`
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "defined_tags", defined_tags)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "logo_file_base64encoded", logo_file_base64encoded)
        pulumi.set(__self__, "logos", logos)
        pulumi.set(__self__, "long_description", long_description)
        pulumi.set(__self__, "package_details", package_details)
        pulumi.set(__self__, "package_type", package_type)
        pulumi.set(__self__, "short_description", short_description)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "time_created", time_created)
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The unique identifier for the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Exact match name filter.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier for the private application in Marketplace.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="logoFileBase64encoded")
    def logo_file_base64encoded(self) -> str:
        return pulumi.get(self, "logo_file_base64encoded")

    @property
    @pulumi.getter
    def logos(self) -> Sequence['outputs.GetPrivateApplicationsPrivateApplicationCollectionItemLogoResult']:
        """
        The model for uploaded binary data, like logos and images.
        """
        return pulumi.get(self, "logos")

    @property
    @pulumi.getter(name="longDescription")
    def long_description(self) -> str:
        """
        A long description of the private application.
        """
        return pulumi.get(self, "long_description")

    @property
    @pulumi.getter(name="packageDetails")
    def package_details(self) -> Sequence['outputs.GetPrivateApplicationsPrivateApplicationCollectionItemPackageDetailResult']:
        return pulumi.get(self, "package_details")

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        Type of packages within this private application.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter(name="shortDescription")
    def short_description(self) -> str:
        """
        A short description of the private application.
        """
        return pulumi.get(self, "short_description")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The lifecycle state of the private application.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the private application was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-26T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the private application was last modified, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-12-10T05:10:29.721Z`
        """
        return pulumi.get(self, "time_updated")


@pulumi.output_type
class GetPrivateApplicationsPrivateApplicationCollectionItemLogoResult(dict):
    def __init__(__self__, *,
                 content_url: str,
                 display_name: str,
                 mime_type: str):
        """
        :param str content_url: The content URL of the uploaded data.
        :param str display_name: Exact match name filter.
        :param str mime_type: The MIME type of the uploaded data.
        """
        pulumi.set(__self__, "content_url", content_url)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "mime_type", mime_type)

    @property
    @pulumi.getter(name="contentUrl")
    def content_url(self) -> str:
        """
        The content URL of the uploaded data.
        """
        return pulumi.get(self, "content_url")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Exact match name filter.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="mimeType")
    def mime_type(self) -> str:
        """
        The MIME type of the uploaded data.
        """
        return pulumi.get(self, "mime_type")


@pulumi.output_type
class GetPrivateApplicationsPrivateApplicationCollectionItemPackageDetailResult(dict):
    def __init__(__self__, *,
                 package_type: str,
                 version: str,
                 zip_file_base64encoded: str):
        """
        :param str package_type: Type of packages within this private application.
        """
        pulumi.set(__self__, "package_type", package_type)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "zip_file_base64encoded", zip_file_base64encoded)

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        Type of packages within this private application.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter
    def version(self) -> str:
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="zipFileBase64encoded")
    def zip_file_base64encoded(self) -> str:
        return pulumi.get(self, "zip_file_base64encoded")


@pulumi.output_type
class GetServiceCatalogAssociationsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetServiceCatalogAssociationsServiceCatalogAssociationCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetServiceCatalogAssociationsServiceCatalogAssociationCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetServiceCatalogAssociationsServiceCatalogAssociationCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetServiceCatalogAssociationsServiceCatalogAssociationCollectionItemResult(dict):
    def __init__(__self__, *,
                 entity_id: str,
                 entity_type: str,
                 id: str,
                 service_catalog_id: str,
                 time_created: str):
        """
        :param str entity_id: The unique identifier of the entity associated with service catalog.
        :param str entity_type: The type of the application in the service catalog.
        :param str id: Identifier of the association.
        :param str service_catalog_id: The unique identifier for the service catalog.
        :param str time_created: Timestamp of when the resource was associated with service catalog.
        """
        pulumi.set(__self__, "entity_id", entity_id)
        pulumi.set(__self__, "entity_type", entity_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "service_catalog_id", service_catalog_id)
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> str:
        """
        The unique identifier of the entity associated with service catalog.
        """
        return pulumi.get(self, "entity_id")

    @property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> str:
        """
        The type of the application in the service catalog.
        """
        return pulumi.get(self, "entity_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Identifier of the association.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceCatalogId")
    def service_catalog_id(self) -> str:
        """
        The unique identifier for the service catalog.
        """
        return pulumi.get(self, "service_catalog_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        Timestamp of when the resource was associated with service catalog.
        """
        return pulumi.get(self, "time_created")


@pulumi.output_type
class GetServiceCatalogsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetServiceCatalogsServiceCatalogCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetServiceCatalogsServiceCatalogCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetServiceCatalogsServiceCatalogCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetServiceCatalogsServiceCatalogCollectionItemResult(dict):
    def __init__(__self__, *,
                 compartment_id: str,
                 defined_tags: Mapping[str, Any],
                 display_name: str,
                 freeform_tags: Mapping[str, Any],
                 id: str,
                 state: str,
                 time_created: str,
                 time_updated: str):
        """
        :param str compartment_id: The unique identifier for the compartment.
        :param Mapping[str, Any] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param str display_name: Exact match name filter.
        :param Mapping[str, Any] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param str id: The unique identifier for the Service catalog.
        :param str state: The lifecycle state of the service catalog.
        :param str time_created: The date and time the service catalog was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-26T21:10:29.600Z`
        :param str time_updated: The date and time the service catalog was last modified, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-12-10T05:10:29.721Z`
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "defined_tags", defined_tags)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "time_created", time_created)
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The unique identifier for the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Exact match name filter.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier for the Service catalog.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The lifecycle state of the service catalog.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the service catalog was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-26T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the service catalog was last modified, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-12-10T05:10:29.721Z`
        """
        return pulumi.get(self, "time_updated")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetLibraryMaskingFormatResult',
    'AwaitableGetLibraryMaskingFormatResult',
    'get_library_masking_format',
    'get_library_masking_format_output',
]

@pulumi.output_type
class GetLibraryMaskingFormatResult:
    """
    A collection of values returned by getLibraryMaskingFormat.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, description=None, display_name=None, format_entries=None, freeform_tags=None, id=None, library_masking_format_id=None, sensitive_type_ids=None, source=None, state=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if format_entries and not isinstance(format_entries, list):
            raise TypeError("Expected argument 'format_entries' to be a list")
        pulumi.set(__self__, "format_entries", format_entries)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if library_masking_format_id and not isinstance(library_masking_format_id, str):
            raise TypeError("Expected argument 'library_masking_format_id' to be a str")
        pulumi.set(__self__, "library_masking_format_id", library_masking_format_id)
        if sensitive_type_ids and not isinstance(sensitive_type_ids, list):
            raise TypeError("Expected argument 'sensitive_type_ids' to be a list")
        pulumi.set(__self__, "sensitive_type_ids", sensitive_type_ids)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains the library masking format.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the format entry.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The display name of the library masking format.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="formatEntries")
    def format_entries(self) -> Sequence['outputs.GetLibraryMaskingFormatFormatEntryResult']:
        """
        An array of format entries. The combined output of all the format entries is used for masking.
        """
        return pulumi.get(self, "format_entries")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the library masking format.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="libraryMaskingFormatId")
    def library_masking_format_id(self) -> str:
        """
        The OCID of the library masking format.
        """
        return pulumi.get(self, "library_masking_format_id")

    @property
    @pulumi.getter(name="sensitiveTypeIds")
    def sensitive_type_ids(self) -> Sequence[str]:
        """
        An array of OCIDs of the sensitive types compatible with the library masking format.
        """
        return pulumi.get(self, "sensitive_type_ids")

    @property
    @pulumi.getter
    def source(self) -> str:
        """
        Specifies whether the library masking format is user-defined or predefined.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the library masking format.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the library masking format was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339)
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the library masking format was updated, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339)
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetLibraryMaskingFormatResult(GetLibraryMaskingFormatResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLibraryMaskingFormatResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            format_entries=self.format_entries,
            freeform_tags=self.freeform_tags,
            id=self.id,
            library_masking_format_id=self.library_masking_format_id,
            sensitive_type_ids=self.sensitive_type_ids,
            source=self.source,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_library_masking_format(library_masking_format_id: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLibraryMaskingFormatResult:
    """
    This data source provides details about a specific Library Masking Format resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of the specified library masking format.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_library_masking_format = oci.DataSafe.get_library_masking_format(library_masking_format_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str library_masking_format_id: The OCID of the library masking format.
    """
    __args__ = dict()
    __args__['libraryMaskingFormatId'] = library_masking_format_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getLibraryMaskingFormat:getLibraryMaskingFormat', __args__, opts=opts, typ=GetLibraryMaskingFormatResult).value

    return AwaitableGetLibraryMaskingFormatResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        format_entries=__ret__.format_entries,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        library_masking_format_id=__ret__.library_masking_format_id,
        sensitive_type_ids=__ret__.sensitive_type_ids,
        source=__ret__.source,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_library_masking_format)
def get_library_masking_format_output(library_masking_format_id: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLibraryMaskingFormatResult]:
    """
    This data source provides details about a specific Library Masking Format resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of the specified library masking format.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_library_masking_format = oci.DataSafe.get_library_masking_format(library_masking_format_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str library_masking_format_id: The OCID of the library masking format.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMediaAssetsResult',
    'AwaitableGetMediaAssetsResult',
    'get_media_assets',
    'get_media_assets_output',
]

@pulumi.output_type
class GetMediaAssetsResult:
    """
    A collection of values returned by getMediaAssets.
    """
    def __init__(__self__, bucket=None, compartment_id=None, display_name=None, distribution_channel_id=None, filters=None, id=None, master_media_asset_id=None, media_asset_collections=None, media_workflow_job_id=None, object=None, parent_media_asset_id=None, source_media_workflow_id=None, source_media_workflow_version=None, state=None, type=None):
        if bucket and not isinstance(bucket, str):
            raise TypeError("Expected argument 'bucket' to be a str")
        pulumi.set(__self__, "bucket", bucket)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if distribution_channel_id and not isinstance(distribution_channel_id, str):
            raise TypeError("Expected argument 'distribution_channel_id' to be a str")
        pulumi.set(__self__, "distribution_channel_id", distribution_channel_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if master_media_asset_id and not isinstance(master_media_asset_id, str):
            raise TypeError("Expected argument 'master_media_asset_id' to be a str")
        pulumi.set(__self__, "master_media_asset_id", master_media_asset_id)
        if media_asset_collections and not isinstance(media_asset_collections, list):
            raise TypeError("Expected argument 'media_asset_collections' to be a list")
        pulumi.set(__self__, "media_asset_collections", media_asset_collections)
        if media_workflow_job_id and not isinstance(media_workflow_job_id, str):
            raise TypeError("Expected argument 'media_workflow_job_id' to be a str")
        pulumi.set(__self__, "media_workflow_job_id", media_workflow_job_id)
        if object and not isinstance(object, str):
            raise TypeError("Expected argument 'object' to be a str")
        pulumi.set(__self__, "object", object)
        if parent_media_asset_id and not isinstance(parent_media_asset_id, str):
            raise TypeError("Expected argument 'parent_media_asset_id' to be a str")
        pulumi.set(__self__, "parent_media_asset_id", parent_media_asset_id)
        if source_media_workflow_id and not isinstance(source_media_workflow_id, str):
            raise TypeError("Expected argument 'source_media_workflow_id' to be a str")
        pulumi.set(__self__, "source_media_workflow_id", source_media_workflow_id)
        if source_media_workflow_version and not isinstance(source_media_workflow_version, str):
            raise TypeError("Expected argument 'source_media_workflow_version' to be a str")
        pulumi.set(__self__, "source_media_workflow_version", source_media_workflow_version)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[str]:
        """
        The name of the object storage bucket where this represented asset is located.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        """
        The ID of the compartment containing the MediaAsset.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="distributionChannelId")
    def distribution_channel_id(self) -> Optional[str]:
        return pulumi.get(self, "distribution_channel_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetMediaAssetsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="masterMediaAssetId")
    def master_media_asset_id(self) -> Optional[str]:
        """
        The ID of the senior most asset from which this asset is derived.
        """
        return pulumi.get(self, "master_media_asset_id")

    @property
    @pulumi.getter(name="mediaAssetCollections")
    def media_asset_collections(self) -> Sequence['outputs.GetMediaAssetsMediaAssetCollectionResult']:
        """
        The list of media_asset_collection.
        """
        return pulumi.get(self, "media_asset_collections")

    @property
    @pulumi.getter(name="mediaWorkflowJobId")
    def media_workflow_job_id(self) -> Optional[str]:
        """
        The ID of the MediaWorkflowJob used to produce this asset.
        """
        return pulumi.get(self, "media_workflow_job_id")

    @property
    @pulumi.getter
    def object(self) -> Optional[str]:
        """
        The object storage object name that identifies this asset.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter(name="parentMediaAssetId")
    def parent_media_asset_id(self) -> Optional[str]:
        """
        The ID of the parent asset from which this asset is derived.
        """
        return pulumi.get(self, "parent_media_asset_id")

    @property
    @pulumi.getter(name="sourceMediaWorkflowId")
    def source_media_workflow_id(self) -> Optional[str]:
        """
        The ID of the MediaWorkflow used to produce this asset.
        """
        return pulumi.get(self, "source_media_workflow_id")

    @property
    @pulumi.getter(name="sourceMediaWorkflowVersion")
    def source_media_workflow_version(self) -> Optional[str]:
        """
        The version of the MediaWorkflow used to produce this asset.
        """
        return pulumi.get(self, "source_media_workflow_version")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the MediaAsset.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        The type of the media asset.
        """
        return pulumi.get(self, "type")


class AwaitableGetMediaAssetsResult(GetMediaAssetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMediaAssetsResult(
            bucket=self.bucket,
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            distribution_channel_id=self.distribution_channel_id,
            filters=self.filters,
            id=self.id,
            master_media_asset_id=self.master_media_asset_id,
            media_asset_collections=self.media_asset_collections,
            media_workflow_job_id=self.media_workflow_job_id,
            object=self.object,
            parent_media_asset_id=self.parent_media_asset_id,
            source_media_workflow_id=self.source_media_workflow_id,
            source_media_workflow_version=self.source_media_workflow_version,
            state=self.state,
            type=self.type)


def get_media_assets(bucket: Optional[str] = None,
                     compartment_id: Optional[str] = None,
                     display_name: Optional[str] = None,
                     distribution_channel_id: Optional[str] = None,
                     filters: Optional[Sequence[pulumi.InputType['GetMediaAssetsFilterArgs']]] = None,
                     master_media_asset_id: Optional[str] = None,
                     media_workflow_job_id: Optional[str] = None,
                     object: Optional[str] = None,
                     parent_media_asset_id: Optional[str] = None,
                     source_media_workflow_id: Optional[str] = None,
                     source_media_workflow_version: Optional[str] = None,
                     state: Optional[str] = None,
                     type: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMediaAssetsResult:
    """
    This data source provides the list of Media Assets in Oracle Cloud Infrastructure Media Services service.

    Returns a list of MediaAssetSummary.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_media_assets = oci.MediaServices.get_media_assets(bucket=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        distribution_channel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        master_media_asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        media_workflow_job_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        object=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        parent_media_asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_media_workflow_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_media_workflow_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str bucket: Filter MediaAsset by the bucket where the object is stored.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only the resources that match the entire display name given.
    :param str distribution_channel_id: Unique DistributionChannel identifier.
    :param str master_media_asset_id: Unique MediaAsset identifier of the first asset upload.
    :param str media_workflow_job_id: The ID of the MediaWorkflowJob used to produce this asset, if this parameter is supplied then the workflow ID must also be supplied.
    :param str object: Filter MediaAsset by the name of the object in object storage.
    :param str parent_media_asset_id: Unique MediaAsset identifier of the asset from which this asset is derived.
    :param str source_media_workflow_id: The ID of the MediaWorkflow used to produce this asset.
    :param str source_media_workflow_version: The version of the MediaWorkflow used to produce this asset.
    :param str state: A filter to return only the resources with lifecycleState matching the given lifecycleState.
    :param str type: Filter MediaAsset by the asset type.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['distributionChannelId'] = distribution_channel_id
    __args__['filters'] = filters
    __args__['masterMediaAssetId'] = master_media_asset_id
    __args__['mediaWorkflowJobId'] = media_workflow_job_id
    __args__['object'] = object
    __args__['parentMediaAssetId'] = parent_media_asset_id
    __args__['sourceMediaWorkflowId'] = source_media_workflow_id
    __args__['sourceMediaWorkflowVersion'] = source_media_workflow_version
    __args__['state'] = state
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:MediaServices/getMediaAssets:getMediaAssets', __args__, opts=opts, typ=GetMediaAssetsResult).value

    return AwaitableGetMediaAssetsResult(
        bucket=__ret__.bucket,
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        distribution_channel_id=__ret__.distribution_channel_id,
        filters=__ret__.filters,
        id=__ret__.id,
        master_media_asset_id=__ret__.master_media_asset_id,
        media_asset_collections=__ret__.media_asset_collections,
        media_workflow_job_id=__ret__.media_workflow_job_id,
        object=__ret__.object,
        parent_media_asset_id=__ret__.parent_media_asset_id,
        source_media_workflow_id=__ret__.source_media_workflow_id,
        source_media_workflow_version=__ret__.source_media_workflow_version,
        state=__ret__.state,
        type=__ret__.type)


@_utilities.lift_output_func(get_media_assets)
def get_media_assets_output(bucket: Optional[pulumi.Input[Optional[str]]] = None,
                            compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                            display_name: Optional[pulumi.Input[Optional[str]]] = None,
                            distribution_channel_id: Optional[pulumi.Input[Optional[str]]] = None,
                            filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetMediaAssetsFilterArgs']]]]] = None,
                            master_media_asset_id: Optional[pulumi.Input[Optional[str]]] = None,
                            media_workflow_job_id: Optional[pulumi.Input[Optional[str]]] = None,
                            object: Optional[pulumi.Input[Optional[str]]] = None,
                            parent_media_asset_id: Optional[pulumi.Input[Optional[str]]] = None,
                            source_media_workflow_id: Optional[pulumi.Input[Optional[str]]] = None,
                            source_media_workflow_version: Optional[pulumi.Input[Optional[str]]] = None,
                            state: Optional[pulumi.Input[Optional[str]]] = None,
                            type: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMediaAssetsResult]:
    """
    This data source provides the list of Media Assets in Oracle Cloud Infrastructure Media Services service.

    Returns a list of MediaAssetSummary.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_media_assets = oci.MediaServices.get_media_assets(bucket=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        distribution_channel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        master_media_asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        media_workflow_job_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        object=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        parent_media_asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_media_workflow_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_media_workflow_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str bucket: Filter MediaAsset by the bucket where the object is stored.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only the resources that match the entire display name given.
    :param str distribution_channel_id: Unique DistributionChannel identifier.
    :param str master_media_asset_id: Unique MediaAsset identifier of the first asset upload.
    :param str media_workflow_job_id: The ID of the MediaWorkflowJob used to produce this asset, if this parameter is supplied then the workflow ID must also be supplied.
    :param str object: Filter MediaAsset by the name of the object in object storage.
    :param str parent_media_asset_id: Unique MediaAsset identifier of the asset from which this asset is derived.
    :param str source_media_workflow_id: The ID of the MediaWorkflow used to produce this asset.
    :param str source_media_workflow_version: The version of the MediaWorkflow used to produce this asset.
    :param str state: A filter to return only the resources with lifecycleState matching the given lifecycleState.
    :param str type: Filter MediaAsset by the asset type.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetInstVbsInstanceResult',
    'AwaitableGetInstVbsInstanceResult',
    'get_inst_vbs_instance',
    'get_inst_vbs_instance_output',
]

@pulumi.output_type
class GetInstVbsInstanceResult:
    """
    A collection of values returned by getInstVbsInstance.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, display_name=None, freeform_tags=None, id=None, idcs_access_token=None, is_resource_usage_agreement_granted=None, lifecyle_details=None, name=None, resource_compartment_id=None, state=None, system_tags=None, time_created=None, time_updated=None, vbs_access_url=None, vbs_instance_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if idcs_access_token and not isinstance(idcs_access_token, str):
            raise TypeError("Expected argument 'idcs_access_token' to be a str")
        pulumi.set(__self__, "idcs_access_token", idcs_access_token)
        if is_resource_usage_agreement_granted and not isinstance(is_resource_usage_agreement_granted, bool):
            raise TypeError("Expected argument 'is_resource_usage_agreement_granted' to be a bool")
        pulumi.set(__self__, "is_resource_usage_agreement_granted", is_resource_usage_agreement_granted)
        if lifecyle_details and not isinstance(lifecyle_details, str):
            raise TypeError("Expected argument 'lifecyle_details' to be a str")
        pulumi.set(__self__, "lifecyle_details", lifecyle_details)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_compartment_id and not isinstance(resource_compartment_id, str):
            raise TypeError("Expected argument 'resource_compartment_id' to be a str")
        pulumi.set(__self__, "resource_compartment_id", resource_compartment_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if vbs_access_url and not isinstance(vbs_access_url, str):
            raise TypeError("Expected argument 'vbs_access_url' to be a str")
        pulumi.set(__self__, "vbs_access_url", vbs_access_url)
        if vbs_instance_id and not isinstance(vbs_instance_id, str):
            raise TypeError("Expected argument 'vbs_instance_id' to be a str")
        pulumi.set(__self__, "vbs_instance_id", vbs_instance_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment of the service instance
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Service instance display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier that is immutable on creation
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> str:
        return pulumi.get(self, "idcs_access_token")

    @property
    @pulumi.getter(name="isResourceUsageAgreementGranted")
    def is_resource_usage_agreement_granted(self) -> bool:
        """
        Whether the VBS service instance owner explicitly approved VBS to create and use resources in the customer tenancy
        """
        return pulumi.get(self, "is_resource_usage_agreement_granted")

    @property
    @pulumi.getter(name="lifecyleDetails")
    def lifecyle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecyle_details")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Service instance name (unique identifier)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceCompartmentId")
    def resource_compartment_id(self) -> str:
        """
        Compartment where VBS may create additional resources for the service instance
        """
        return pulumi.get(self, "resource_compartment_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the VbsInstance.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the the VbsInstance was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the VbsInstance was updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="vbsAccessUrl")
    def vbs_access_url(self) -> str:
        """
        Public web URL for accessing the VBS service instance
        """
        return pulumi.get(self, "vbs_access_url")

    @property
    @pulumi.getter(name="vbsInstanceId")
    def vbs_instance_id(self) -> str:
        return pulumi.get(self, "vbs_instance_id")


class AwaitableGetInstVbsInstanceResult(GetInstVbsInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstVbsInstanceResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            id=self.id,
            idcs_access_token=self.idcs_access_token,
            is_resource_usage_agreement_granted=self.is_resource_usage_agreement_granted,
            lifecyle_details=self.lifecyle_details,
            name=self.name,
            resource_compartment_id=self.resource_compartment_id,
            state=self.state,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated,
            vbs_access_url=self.vbs_access_url,
            vbs_instance_id=self.vbs_instance_id)


def get_inst_vbs_instance(vbs_instance_id: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstVbsInstanceResult:
    """
    This data source provides details about a specific Vbs Instance resource in Oracle Cloud Infrastructure Vbs Inst service.

    Gets a VbsInstance by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vbs_instance = oci.Vbs.get_inst_vbs_instance(vbs_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str vbs_instance_id: unique VbsInstance identifier
    """
    __args__ = dict()
    __args__['vbsInstanceId'] = vbs_instance_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Vbs/getInstVbsInstance:getInstVbsInstance', __args__, opts=opts, typ=GetInstVbsInstanceResult).value

    return AwaitableGetInstVbsInstanceResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        idcs_access_token=__ret__.idcs_access_token,
        is_resource_usage_agreement_granted=__ret__.is_resource_usage_agreement_granted,
        lifecyle_details=__ret__.lifecyle_details,
        name=__ret__.name,
        resource_compartment_id=__ret__.resource_compartment_id,
        state=__ret__.state,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated,
        vbs_access_url=__ret__.vbs_access_url,
        vbs_instance_id=__ret__.vbs_instance_id)


@_utilities.lift_output_func(get_inst_vbs_instance)
def get_inst_vbs_instance_output(vbs_instance_id: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstVbsInstanceResult]:
    """
    This data source provides details about a specific Vbs Instance resource in Oracle Cloud Infrastructure Vbs Inst service.

    Gets a VbsInstance by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vbs_instance = oci.Vbs.get_inst_vbs_instance(vbs_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str vbs_instance_id: unique VbsInstance identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomTableArgs', 'CustomTable']

@pulumi.input_type
class CustomTableArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 saved_custom_table: pulumi.Input['CustomTableSavedCustomTableArgs'],
                 saved_report_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a CustomTable resource.
        :param pulumi.Input[str] compartment_id: The compartment OCID.
        :param pulumi.Input['CustomTableSavedCustomTableArgs'] saved_custom_table: (Updatable) The custom table for Cost Analysis UI rendering.
        :param pulumi.Input[str] saved_report_id: The associated saved report OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "saved_custom_table", saved_custom_table)
        pulumi.set(__self__, "saved_report_id", saved_report_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        The compartment OCID.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="savedCustomTable")
    def saved_custom_table(self) -> pulumi.Input['CustomTableSavedCustomTableArgs']:
        """
        (Updatable) The custom table for Cost Analysis UI rendering.
        """
        return pulumi.get(self, "saved_custom_table")

    @saved_custom_table.setter
    def saved_custom_table(self, value: pulumi.Input['CustomTableSavedCustomTableArgs']):
        pulumi.set(self, "saved_custom_table", value)

    @property
    @pulumi.getter(name="savedReportId")
    def saved_report_id(self) -> pulumi.Input[str]:
        """
        The associated saved report OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "saved_report_id")

    @saved_report_id.setter
    def saved_report_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "saved_report_id", value)


@pulumi.input_type
class _CustomTableState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 saved_custom_table: Optional[pulumi.Input['CustomTableSavedCustomTableArgs']] = None,
                 saved_report_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CustomTable resources.
        :param pulumi.Input[str] compartment_id: The compartment OCID.
        :param pulumi.Input['CustomTableSavedCustomTableArgs'] saved_custom_table: (Updatable) The custom table for Cost Analysis UI rendering.
        :param pulumi.Input[str] saved_report_id: The associated saved report OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if saved_custom_table is not None:
            pulumi.set(__self__, "saved_custom_table", saved_custom_table)
        if saved_report_id is not None:
            pulumi.set(__self__, "saved_report_id", saved_report_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The compartment OCID.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="savedCustomTable")
    def saved_custom_table(self) -> Optional[pulumi.Input['CustomTableSavedCustomTableArgs']]:
        """
        (Updatable) The custom table for Cost Analysis UI rendering.
        """
        return pulumi.get(self, "saved_custom_table")

    @saved_custom_table.setter
    def saved_custom_table(self, value: Optional[pulumi.Input['CustomTableSavedCustomTableArgs']]):
        pulumi.set(self, "saved_custom_table", value)

    @property
    @pulumi.getter(name="savedReportId")
    def saved_report_id(self) -> Optional[pulumi.Input[str]]:
        """
        The associated saved report OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "saved_report_id")

    @saved_report_id.setter
    def saved_report_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saved_report_id", value)


class CustomTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 saved_custom_table: Optional[pulumi.Input[pulumi.InputType['CustomTableSavedCustomTableArgs']]] = None,
                 saved_report_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Custom Table resource in Oracle Cloud Infrastructure Metering Computation service.

        Returns the created custom table.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_custom_table = oci.metering_computation.CustomTable("testCustomTable",
            compartment_id=var["compartment_id"],
            saved_custom_table=oci.metering_computation.CustomTableSavedCustomTableArgs(
                display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                column_group_bies=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                compartment_depth=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                group_by_tags=[oci.metering_computation.CustomTableSavedCustomTableGroupByTagArgs(
                    key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                row_group_bies=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            saved_report_id=oci_metering_computation_saved_report["test_saved_report"]["id"])
        ```

        ## Import

        CustomTables can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:MeteringComputation/customTable:CustomTable test_custom_table "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The compartment OCID.
        :param pulumi.Input[pulumi.InputType['CustomTableSavedCustomTableArgs']] saved_custom_table: (Updatable) The custom table for Cost Analysis UI rendering.
        :param pulumi.Input[str] saved_report_id: The associated saved report OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomTableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Custom Table resource in Oracle Cloud Infrastructure Metering Computation service.

        Returns the created custom table.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_custom_table = oci.metering_computation.CustomTable("testCustomTable",
            compartment_id=var["compartment_id"],
            saved_custom_table=oci.metering_computation.CustomTableSavedCustomTableArgs(
                display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                column_group_bies=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                compartment_depth=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                group_by_tags=[oci.metering_computation.CustomTableSavedCustomTableGroupByTagArgs(
                    key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                row_group_bies=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            saved_report_id=oci_metering_computation_saved_report["test_saved_report"]["id"])
        ```

        ## Import

        CustomTables can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:MeteringComputation/customTable:CustomTable test_custom_table "id"
        ```

        :param str resource_name: The name of the resource.
        :param CustomTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 saved_custom_table: Optional[pulumi.Input[pulumi.InputType['CustomTableSavedCustomTableArgs']]] = None,
                 saved_report_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomTableArgs.__new__(CustomTableArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            if saved_custom_table is None and not opts.urn:
                raise TypeError("Missing required property 'saved_custom_table'")
            __props__.__dict__["saved_custom_table"] = saved_custom_table
            if saved_report_id is None and not opts.urn:
                raise TypeError("Missing required property 'saved_report_id'")
            __props__.__dict__["saved_report_id"] = saved_report_id
        super(CustomTable, __self__).__init__(
            'oci:MeteringComputation/customTable:CustomTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            saved_custom_table: Optional[pulumi.Input[pulumi.InputType['CustomTableSavedCustomTableArgs']]] = None,
            saved_report_id: Optional[pulumi.Input[str]] = None) -> 'CustomTable':
        """
        Get an existing CustomTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The compartment OCID.
        :param pulumi.Input[pulumi.InputType['CustomTableSavedCustomTableArgs']] saved_custom_table: (Updatable) The custom table for Cost Analysis UI rendering.
        :param pulumi.Input[str] saved_report_id: The associated saved report OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomTableState.__new__(_CustomTableState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["saved_custom_table"] = saved_custom_table
        __props__.__dict__["saved_report_id"] = saved_report_id
        return CustomTable(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The compartment OCID.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="savedCustomTable")
    def saved_custom_table(self) -> pulumi.Output['outputs.CustomTableSavedCustomTable']:
        """
        (Updatable) The custom table for Cost Analysis UI rendering.
        """
        return pulumi.get(self, "saved_custom_table")

    @property
    @pulumi.getter(name="savedReportId")
    def saved_report_id(self) -> pulumi.Output[str]:
        """
        The associated saved report OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "saved_report_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUserAssessmentUsersResult',
    'AwaitableGetUserAssessmentUsersResult',
    'get_user_assessment_users',
    'get_user_assessment_users_output',
]

@pulumi.output_type
class GetUserAssessmentUsersResult:
    """
    A collection of values returned by getUserAssessmentUsers.
    """
    def __init__(__self__, access_level=None, account_status=None, authentication_type=None, compartment_id_in_subtree=None, filters=None, id=None, target_id=None, time_last_login_greater_than_or_equal_to=None, time_last_login_less_than=None, time_password_last_changed_greater_than_or_equal_to=None, time_password_last_changed_less_than=None, time_user_created_greater_than_or_equal_to=None, time_user_created_less_than=None, user_assessment_id=None, user_category=None, user_key=None, user_name=None, user_profile=None, user_role=None, user_type=None, users=None):
        if access_level and not isinstance(access_level, str):
            raise TypeError("Expected argument 'access_level' to be a str")
        pulumi.set(__self__, "access_level", access_level)
        if account_status and not isinstance(account_status, str):
            raise TypeError("Expected argument 'account_status' to be a str")
        pulumi.set(__self__, "account_status", account_status)
        if authentication_type and not isinstance(authentication_type, str):
            raise TypeError("Expected argument 'authentication_type' to be a str")
        pulumi.set(__self__, "authentication_type", authentication_type)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if target_id and not isinstance(target_id, str):
            raise TypeError("Expected argument 'target_id' to be a str")
        pulumi.set(__self__, "target_id", target_id)
        if time_last_login_greater_than_or_equal_to and not isinstance(time_last_login_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'time_last_login_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "time_last_login_greater_than_or_equal_to", time_last_login_greater_than_or_equal_to)
        if time_last_login_less_than and not isinstance(time_last_login_less_than, str):
            raise TypeError("Expected argument 'time_last_login_less_than' to be a str")
        pulumi.set(__self__, "time_last_login_less_than", time_last_login_less_than)
        if time_password_last_changed_greater_than_or_equal_to and not isinstance(time_password_last_changed_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'time_password_last_changed_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "time_password_last_changed_greater_than_or_equal_to", time_password_last_changed_greater_than_or_equal_to)
        if time_password_last_changed_less_than and not isinstance(time_password_last_changed_less_than, str):
            raise TypeError("Expected argument 'time_password_last_changed_less_than' to be a str")
        pulumi.set(__self__, "time_password_last_changed_less_than", time_password_last_changed_less_than)
        if time_user_created_greater_than_or_equal_to and not isinstance(time_user_created_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'time_user_created_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "time_user_created_greater_than_or_equal_to", time_user_created_greater_than_or_equal_to)
        if time_user_created_less_than and not isinstance(time_user_created_less_than, str):
            raise TypeError("Expected argument 'time_user_created_less_than' to be a str")
        pulumi.set(__self__, "time_user_created_less_than", time_user_created_less_than)
        if user_assessment_id and not isinstance(user_assessment_id, str):
            raise TypeError("Expected argument 'user_assessment_id' to be a str")
        pulumi.set(__self__, "user_assessment_id", user_assessment_id)
        if user_category and not isinstance(user_category, str):
            raise TypeError("Expected argument 'user_category' to be a str")
        pulumi.set(__self__, "user_category", user_category)
        if user_key and not isinstance(user_key, str):
            raise TypeError("Expected argument 'user_key' to be a str")
        pulumi.set(__self__, "user_key", user_key)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)
        if user_profile and not isinstance(user_profile, str):
            raise TypeError("Expected argument 'user_profile' to be a str")
        pulumi.set(__self__, "user_profile", user_profile)
        if user_role and not isinstance(user_role, str):
            raise TypeError("Expected argument 'user_role' to be a str")
        pulumi.set(__self__, "user_role", user_role)
        if user_type and not isinstance(user_type, str):
            raise TypeError("Expected argument 'user_type' to be a str")
        pulumi.set(__self__, "user_type", user_type)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[str]:
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> Optional[str]:
        """
        The user account status.
        """
        return pulumi.get(self, "account_status")

    @property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> Optional[str]:
        """
        The user authentication method.
        """
        return pulumi.get(self, "authentication_type")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetUserAssessmentUsersFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> Optional[str]:
        """
        The OCID of the target database.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter(name="timeLastLoginGreaterThanOrEqualTo")
    def time_last_login_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "time_last_login_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timeLastLoginLessThan")
    def time_last_login_less_than(self) -> Optional[str]:
        return pulumi.get(self, "time_last_login_less_than")

    @property
    @pulumi.getter(name="timePasswordLastChangedGreaterThanOrEqualTo")
    def time_password_last_changed_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "time_password_last_changed_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timePasswordLastChangedLessThan")
    def time_password_last_changed_less_than(self) -> Optional[str]:
        return pulumi.get(self, "time_password_last_changed_less_than")

    @property
    @pulumi.getter(name="timeUserCreatedGreaterThanOrEqualTo")
    def time_user_created_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "time_user_created_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timeUserCreatedLessThan")
    def time_user_created_less_than(self) -> Optional[str]:
        return pulumi.get(self, "time_user_created_less_than")

    @property
    @pulumi.getter(name="userAssessmentId")
    def user_assessment_id(self) -> str:
        return pulumi.get(self, "user_assessment_id")

    @property
    @pulumi.getter(name="userCategory")
    def user_category(self) -> Optional[str]:
        """
        The user category based on the privileges and other details of the user.
        """
        return pulumi.get(self, "user_category")

    @property
    @pulumi.getter(name="userKey")
    def user_key(self) -> Optional[str]:
        return pulumi.get(self, "user_key")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[str]:
        """
        The database user name.
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userProfile")
    def user_profile(self) -> Optional[str]:
        """
        The user profile name.
        """
        return pulumi.get(self, "user_profile")

    @property
    @pulumi.getter(name="userRole")
    def user_role(self) -> Optional[str]:
        return pulumi.get(self, "user_role")

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[str]:
        return pulumi.get(self, "user_type")

    @property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetUserAssessmentUsersUserResult']:
        """
        The list of users.
        """
        return pulumi.get(self, "users")


class AwaitableGetUserAssessmentUsersResult(GetUserAssessmentUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserAssessmentUsersResult(
            access_level=self.access_level,
            account_status=self.account_status,
            authentication_type=self.authentication_type,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            filters=self.filters,
            id=self.id,
            target_id=self.target_id,
            time_last_login_greater_than_or_equal_to=self.time_last_login_greater_than_or_equal_to,
            time_last_login_less_than=self.time_last_login_less_than,
            time_password_last_changed_greater_than_or_equal_to=self.time_password_last_changed_greater_than_or_equal_to,
            time_password_last_changed_less_than=self.time_password_last_changed_less_than,
            time_user_created_greater_than_or_equal_to=self.time_user_created_greater_than_or_equal_to,
            time_user_created_less_than=self.time_user_created_less_than,
            user_assessment_id=self.user_assessment_id,
            user_category=self.user_category,
            user_key=self.user_key,
            user_name=self.user_name,
            user_profile=self.user_profile,
            user_role=self.user_role,
            user_type=self.user_type,
            users=self.users)


def get_user_assessment_users(access_level: Optional[str] = None,
                              account_status: Optional[str] = None,
                              authentication_type: Optional[str] = None,
                              compartment_id_in_subtree: Optional[bool] = None,
                              filters: Optional[Sequence[pulumi.InputType['GetUserAssessmentUsersFilterArgs']]] = None,
                              target_id: Optional[str] = None,
                              time_last_login_greater_than_or_equal_to: Optional[str] = None,
                              time_last_login_less_than: Optional[str] = None,
                              time_password_last_changed_greater_than_or_equal_to: Optional[str] = None,
                              time_password_last_changed_less_than: Optional[str] = None,
                              time_user_created_greater_than_or_equal_to: Optional[str] = None,
                              time_user_created_less_than: Optional[str] = None,
                              user_assessment_id: Optional[str] = None,
                              user_category: Optional[str] = None,
                              user_key: Optional[str] = None,
                              user_name: Optional[str] = None,
                              user_profile: Optional[str] = None,
                              user_role: Optional[str] = None,
                              user_type: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserAssessmentUsersResult:
    """
    This data source provides the list of User Assessment Users in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of users of the specified user assessment. The result contains the database user details for each user, such
    as user type, account status, last login time, user creation time, authentication type, user profile, and the date and time
    of the latest password change. It also contains the user category derived from these user details as well as privileges
    granted to each user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_user_assessment_users = oci.DataSafe.get_user_assessment_users(user_assessment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        account_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        authentication_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_last_login_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_last_login_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_password_last_changed_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_password_last_changed_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_user_created_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_user_created_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_category=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_profile=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_role=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str account_status: A filter to return only items that match the specified account status.
    :param str authentication_type: A filter to return only items that match the specified authentication type.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str target_id: A filter to return only items related to a specific target OCID.
    :param str time_last_login_greater_than_or_equal_to: A filter to return users whose last login time in the database is greater than or equal to the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_last_login_less_than: A filter to return users whose last login time in the database is less than the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). **Example:** 2016-12-19T16:39:57.600Z
    :param str time_password_last_changed_greater_than_or_equal_to: A filter to return users whose last password change in the database is greater than or equal to the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_password_last_changed_less_than: A filter to return users whose last password change in the database is less than the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_user_created_greater_than_or_equal_to: A filter to return users whose creation time in the database is greater than or equal to the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). **Example:** 2016-12-19T16:39:57.600Z
    :param str time_user_created_less_than: A filter to return users whose creation time in the database is less than the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). **Example:** 2016-12-19T16:39:57.600Z
    :param str user_assessment_id: The OCID of the user assessment.
    :param str user_category: A filter to return only items that match the specified user category.
    :param str user_key: A filter to return only items that match the specified user key.
    :param str user_name: A filter to return only items that match the specified user name.
    :param str user_profile: A filter to return only items that match the specified user profile.
    :param str user_role: A filter to return only items that match the specified user role.
    :param str user_type: A filter to return only items that match the specified user type. The possible values can be
           * ADMIN_PRIVILEGED
           * APPLICATION
           * PRIVILEGED
           * SCHEMA
           * NON_PRIVILEGED as specified by '#/definitions/userTypes'.
    """
    __args__ = dict()
    __args__['accessLevel'] = access_level
    __args__['accountStatus'] = account_status
    __args__['authenticationType'] = authentication_type
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['filters'] = filters
    __args__['targetId'] = target_id
    __args__['timeLastLoginGreaterThanOrEqualTo'] = time_last_login_greater_than_or_equal_to
    __args__['timeLastLoginLessThan'] = time_last_login_less_than
    __args__['timePasswordLastChangedGreaterThanOrEqualTo'] = time_password_last_changed_greater_than_or_equal_to
    __args__['timePasswordLastChangedLessThan'] = time_password_last_changed_less_than
    __args__['timeUserCreatedGreaterThanOrEqualTo'] = time_user_created_greater_than_or_equal_to
    __args__['timeUserCreatedLessThan'] = time_user_created_less_than
    __args__['userAssessmentId'] = user_assessment_id
    __args__['userCategory'] = user_category
    __args__['userKey'] = user_key
    __args__['userName'] = user_name
    __args__['userProfile'] = user_profile
    __args__['userRole'] = user_role
    __args__['userType'] = user_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getUserAssessmentUsers:getUserAssessmentUsers', __args__, opts=opts, typ=GetUserAssessmentUsersResult).value

    return AwaitableGetUserAssessmentUsersResult(
        access_level=__ret__.access_level,
        account_status=__ret__.account_status,
        authentication_type=__ret__.authentication_type,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        filters=__ret__.filters,
        id=__ret__.id,
        target_id=__ret__.target_id,
        time_last_login_greater_than_or_equal_to=__ret__.time_last_login_greater_than_or_equal_to,
        time_last_login_less_than=__ret__.time_last_login_less_than,
        time_password_last_changed_greater_than_or_equal_to=__ret__.time_password_last_changed_greater_than_or_equal_to,
        time_password_last_changed_less_than=__ret__.time_password_last_changed_less_than,
        time_user_created_greater_than_or_equal_to=__ret__.time_user_created_greater_than_or_equal_to,
        time_user_created_less_than=__ret__.time_user_created_less_than,
        user_assessment_id=__ret__.user_assessment_id,
        user_category=__ret__.user_category,
        user_key=__ret__.user_key,
        user_name=__ret__.user_name,
        user_profile=__ret__.user_profile,
        user_role=__ret__.user_role,
        user_type=__ret__.user_type,
        users=__ret__.users)


@_utilities.lift_output_func(get_user_assessment_users)
def get_user_assessment_users_output(access_level: Optional[pulumi.Input[Optional[str]]] = None,
                                     account_status: Optional[pulumi.Input[Optional[str]]] = None,
                                     authentication_type: Optional[pulumi.Input[Optional[str]]] = None,
                                     compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                                     filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetUserAssessmentUsersFilterArgs']]]]] = None,
                                     target_id: Optional[pulumi.Input[Optional[str]]] = None,
                                     time_last_login_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                     time_last_login_less_than: Optional[pulumi.Input[Optional[str]]] = None,
                                     time_password_last_changed_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                     time_password_last_changed_less_than: Optional[pulumi.Input[Optional[str]]] = None,
                                     time_user_created_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                     time_user_created_less_than: Optional[pulumi.Input[Optional[str]]] = None,
                                     user_assessment_id: Optional[pulumi.Input[str]] = None,
                                     user_category: Optional[pulumi.Input[Optional[str]]] = None,
                                     user_key: Optional[pulumi.Input[Optional[str]]] = None,
                                     user_name: Optional[pulumi.Input[Optional[str]]] = None,
                                     user_profile: Optional[pulumi.Input[Optional[str]]] = None,
                                     user_role: Optional[pulumi.Input[Optional[str]]] = None,
                                     user_type: Optional[pulumi.Input[Optional[str]]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUserAssessmentUsersResult]:
    """
    This data source provides the list of User Assessment Users in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of users of the specified user assessment. The result contains the database user details for each user, such
    as user type, account status, last login time, user creation time, authentication type, user profile, and the date and time
    of the latest password change. It also contains the user category derived from these user details as well as privileges
    granted to each user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_user_assessment_users = oci.DataSafe.get_user_assessment_users(user_assessment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        account_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        authentication_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_last_login_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_last_login_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_password_last_changed_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_password_last_changed_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_user_created_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_user_created_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_category=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_profile=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_role=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str account_status: A filter to return only items that match the specified account status.
    :param str authentication_type: A filter to return only items that match the specified authentication type.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str target_id: A filter to return only items related to a specific target OCID.
    :param str time_last_login_greater_than_or_equal_to: A filter to return users whose last login time in the database is greater than or equal to the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_last_login_less_than: A filter to return users whose last login time in the database is less than the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). **Example:** 2016-12-19T16:39:57.600Z
    :param str time_password_last_changed_greater_than_or_equal_to: A filter to return users whose last password change in the database is greater than or equal to the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_password_last_changed_less_than: A filter to return users whose last password change in the database is less than the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
           
           **Example:** 2016-12-19T16:39:57.600Z
    :param str time_user_created_greater_than_or_equal_to: A filter to return users whose creation time in the database is greater than or equal to the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). **Example:** 2016-12-19T16:39:57.600Z
    :param str time_user_created_less_than: A filter to return users whose creation time in the database is less than the date and time specified, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339). **Example:** 2016-12-19T16:39:57.600Z
    :param str user_assessment_id: The OCID of the user assessment.
    :param str user_category: A filter to return only items that match the specified user category.
    :param str user_key: A filter to return only items that match the specified user key.
    :param str user_name: A filter to return only items that match the specified user name.
    :param str user_profile: A filter to return only items that match the specified user profile.
    :param str user_role: A filter to return only items that match the specified user role.
    :param str user_type: A filter to return only items that match the specified user type. The possible values can be
           * ADMIN_PRIVILEGED
           * APPLICATION
           * PRIVILEGED
           * SCHEMA
           * NON_PRIVILEGED as specified by '#/definitions/userTypes'.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetModelProvenanceResult',
    'AwaitableGetModelProvenanceResult',
    'get_model_provenance',
    'get_model_provenance_output',
]

@pulumi.output_type
class GetModelProvenanceResult:
    """
    A collection of values returned by getModelProvenance.
    """
    def __init__(__self__, git_branch=None, git_commit=None, id=None, model_id=None, repository_url=None, script_dir=None, training_id=None, training_script=None):
        if git_branch and not isinstance(git_branch, str):
            raise TypeError("Expected argument 'git_branch' to be a str")
        pulumi.set(__self__, "git_branch", git_branch)
        if git_commit and not isinstance(git_commit, str):
            raise TypeError("Expected argument 'git_commit' to be a str")
        pulumi.set(__self__, "git_commit", git_commit)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if model_id and not isinstance(model_id, str):
            raise TypeError("Expected argument 'model_id' to be a str")
        pulumi.set(__self__, "model_id", model_id)
        if repository_url and not isinstance(repository_url, str):
            raise TypeError("Expected argument 'repository_url' to be a str")
        pulumi.set(__self__, "repository_url", repository_url)
        if script_dir and not isinstance(script_dir, str):
            raise TypeError("Expected argument 'script_dir' to be a str")
        pulumi.set(__self__, "script_dir", script_dir)
        if training_id and not isinstance(training_id, str):
            raise TypeError("Expected argument 'training_id' to be a str")
        pulumi.set(__self__, "training_id", training_id)
        if training_script and not isinstance(training_script, str):
            raise TypeError("Expected argument 'training_script' to be a str")
        pulumi.set(__self__, "training_script", training_script)

    @property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> str:
        """
        For model reproducibility purposes. Branch of the git repository associated with model training.
        """
        return pulumi.get(self, "git_branch")

    @property
    @pulumi.getter(name="gitCommit")
    def git_commit(self) -> str:
        """
        For model reproducibility purposes. Commit ID of the git repository associated with model training.
        """
        return pulumi.get(self, "git_commit")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> str:
        return pulumi.get(self, "model_id")

    @property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> str:
        """
        For model reproducibility purposes. URL of the git repository associated with model training.
        """
        return pulumi.get(self, "repository_url")

    @property
    @pulumi.getter(name="scriptDir")
    def script_dir(self) -> str:
        """
        For model reproducibility purposes. Path to model artifacts.
        """
        return pulumi.get(self, "script_dir")

    @property
    @pulumi.getter(name="trainingId")
    def training_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        """
        return pulumi.get(self, "training_id")

    @property
    @pulumi.getter(name="trainingScript")
    def training_script(self) -> str:
        """
        For model reproducibility purposes. Path to the python script or notebook in which the model was trained."
        """
        return pulumi.get(self, "training_script")


class AwaitableGetModelProvenanceResult(GetModelProvenanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetModelProvenanceResult(
            git_branch=self.git_branch,
            git_commit=self.git_commit,
            id=self.id,
            model_id=self.model_id,
            repository_url=self.repository_url,
            script_dir=self.script_dir,
            training_id=self.training_id,
            training_script=self.training_script)


def get_model_provenance(model_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetModelProvenanceResult:
    """
    This data source provides details about a specific Model Provenance resource in Oracle Cloud Infrastructure Data Science service.

    Gets provenance information for specified model.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_model_provenance = oci.DataScience.get_model_provenance(model_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str model_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
    """
    __args__ = dict()
    __args__['modelId'] = model_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataScience/getModelProvenance:getModelProvenance', __args__, opts=opts, typ=GetModelProvenanceResult).value

    return AwaitableGetModelProvenanceResult(
        git_branch=__ret__.git_branch,
        git_commit=__ret__.git_commit,
        id=__ret__.id,
        model_id=__ret__.model_id,
        repository_url=__ret__.repository_url,
        script_dir=__ret__.script_dir,
        training_id=__ret__.training_id,
        training_script=__ret__.training_script)


@_utilities.lift_output_func(get_model_provenance)
def get_model_provenance_output(model_id: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetModelProvenanceResult]:
    """
    This data source provides details about a specific Model Provenance resource in Oracle Cloud Infrastructure Data Science service.

    Gets provenance information for specified model.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_model_provenance = oci.DataScience.get_model_provenance(model_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str model_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetTagStandardTagNamespaceTemplatesResult',
    'AwaitableGetTagStandardTagNamespaceTemplatesResult',
    'get_tag_standard_tag_namespace_templates',
    'get_tag_standard_tag_namespace_templates_output',
]

@pulumi.output_type
class GetTagStandardTagNamespaceTemplatesResult:
    """
    A collection of values returned by getTagStandardTagNamespaceTemplates.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, standard_tag_namespace_templates=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if standard_tag_namespace_templates and not isinstance(standard_tag_namespace_templates, list):
            raise TypeError("Expected argument 'standard_tag_namespace_templates' to be a list")
        pulumi.set(__self__, "standard_tag_namespace_templates", standard_tag_namespace_templates)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetTagStandardTagNamespaceTemplatesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="standardTagNamespaceTemplates")
    def standard_tag_namespace_templates(self) -> Sequence['outputs.GetTagStandardTagNamespaceTemplatesStandardTagNamespaceTemplateResult']:
        """
        The list of standard_tag_namespace_templates.
        """
        return pulumi.get(self, "standard_tag_namespace_templates")


class AwaitableGetTagStandardTagNamespaceTemplatesResult(GetTagStandardTagNamespaceTemplatesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTagStandardTagNamespaceTemplatesResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            standard_tag_namespace_templates=self.standard_tag_namespace_templates)


def get_tag_standard_tag_namespace_templates(compartment_id: Optional[str] = None,
                                             filters: Optional[Sequence[pulumi.InputType['GetTagStandardTagNamespaceTemplatesFilterArgs']]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTagStandardTagNamespaceTemplatesResult:
    """
    This data source provides the list of Tag Standard Tag Namespace Templates in Oracle Cloud Infrastructure Identity service.

    Lists available standard tag namespaces that users can create.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_tag_standard_tag_namespace_templates = oci.Identity.get_tag_standard_tag_namespace_templates(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getTagStandardTagNamespaceTemplates:getTagStandardTagNamespaceTemplates', __args__, opts=opts, typ=GetTagStandardTagNamespaceTemplatesResult).value

    return AwaitableGetTagStandardTagNamespaceTemplatesResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        standard_tag_namespace_templates=__ret__.standard_tag_namespace_templates)


@_utilities.lift_output_func(get_tag_standard_tag_namespace_templates)
def get_tag_standard_tag_namespace_templates_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetTagStandardTagNamespaceTemplatesFilterArgs']]]]] = None,
                                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTagStandardTagNamespaceTemplatesResult]:
    """
    This data source provides the list of Tag Standard Tag Namespace Templates in Oracle Cloud Infrastructure Identity service.

    Lists available standard tag namespaces that users can create.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_tag_standard_tag_namespace_templates = oci.Identity.get_tag_standard_tag_namespace_templates(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    """
    ...
